.. _tests

Examples
========

The following code is part of the unit tests and should be mostly
self explaining.

models.py
---------

.. literalinclude:: ../../composite_field_test/models.py
    :language: python

tests.py
--------

.. literalinclude:: ../../composite_field/tests.py
    :language: python
